[GRASS-SVN] r47702 - grass/trunk/raster/r.texture
svn_grass at osgeo.org
svn_grass at osgeo.org
Wed Aug 17 08:59:35 EDT 2011
Author: neteler
Date: 2011-08-17 05:59:35 -0700 (Wed, 17 Aug 2011)
New Revision: 47702
Modified:
grass/trunk/raster/r.texture/main.c
Log:
more standardized wording
Modified: grass/trunk/raster/r.texture/main.c
===================================================================
--- grass/trunk/raster/r.texture/main.c 2011-08-17 12:47:55 UTC (rev 47701)
+++ grass/trunk/raster/r.texture/main.c 2011-08-17 12:59:35 UTC (rev 47702)
@@ -84,7 +84,7 @@
struct FPRange range;
DCELL min, max, inscale;
FCELL measure; /* Containing measure done */
- int dist, size; /* dist = value of distance, size = s. of sliding window */
+ int dist, size; /* dist = value of distance, size = s. of moving window */
int offset;
int have_px, have_py, have_sentr, have_pxpys, have_pxpyd;
int infd, *outfd;
@@ -121,7 +121,7 @@
opt_size->key_desc = "value";
opt_size->type = TYPE_INTEGER;
opt_size->required = NO;
- opt_size->description = _("The size of sliding window (odd and >= 3)");
+ opt_size->description = _("The size of moving window (odd and >= 3)");
opt_size->answer = "3";
/* Textural character is in direct relation of the spatial size of the texture primitives. */
@@ -312,7 +312,7 @@
/* *************************************************************************************************
*
* Compute of the matrix S.G.L.D. (Spatial Gray-Level Dependence Matrices) or co-occurrence matrix.
* The image is analized for piece, every piece is naming sliding window (s.w.). The s.w. must be
* square with number of size's samples odd, that because we want the sample at the center of matrix.
*
***************************************************************************************************/
@@ -312,7 +312,7 @@
*
* Compute of the matrix S.G.L.D. (Spatial Gray-Level Dependence Matrices) or co-occurrence matrix.
- * The image is analized for piece, every piece is naming sliding window (s.w.). The s.w. must be
+ * The image is analized for piece, every piece is naming moving window (s.w.). The s.w. must be
* square with number of size's samples odd, that because we want the sample at the center of matrix.
*
More information about the grass-commit
mailing list